@@ -42,6 +42,7 @@ try:
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.cloud.location import locations_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -266,8 +267,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1.types.ListJobsRequest, dict]]):
-                The request object. Request message for listing jobs
-                using
+                The request object. Request message for listing jobs using
                 [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
             parent (:class:`str`):
                 Required. The location name. For example:
@@ -285,7 +285,7 @@ class CloudSchedulerAsyncClient:
         Returns:
             google.cloud.scheduler_v1.services.cloud_scheduler.pagers.ListJobsAsyncPager:
                 Response message for listing jobs using
-                [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
+                   [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -410,7 +410,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -537,7 +537,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -665,7 +665,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -748,8 +748,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1.types.DeleteJobRequest, dict]]):
-                The request object. Request message for deleting a job
-                using
+                The request object. Request message for deleting a job using
                 [DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob].
             name (:class:`str`):
                 Required. The job name. For example:
@@ -882,7 +881,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -995,7 +994,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -1081,8 +1080,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1.types.RunJobRequest, dict]]):
-                The request object. Request message for forcing a job to
-                run now using
+                The request object. Request message for forcing a job to run now using
                 [RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob].
             name (:class:`str`):
                 Required. The job name. For example:
@@ -1101,7 +1099,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -1146,6 +1144,114 @@ class CloudSchedulerAsyncClient:
         # Done; return the response.
         return response
 
+    async def get_location(
+        self,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.Location:
+        r"""Gets information about a location.
+
+        Args:
+            request (:class:`~.location_pb2.GetLocationRequest`):
+                The request object. Request message for
+                `GetLocation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.Location:
+                Location object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.GetLocationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.get_location,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def list_locations(
+        self,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.ListLocationsResponse:
+        r"""Lists information about the supported locations for this service.
+
+        Args:
+            request (:class:`~.location_pb2.ListLocationsRequest`):
+                The request object. Request message for
+                `ListLocations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.ListLocationsResponse:
+                Response message for ``ListLocations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.ListLocationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.list_locations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
