@@ -26,6 +26,7 @@ from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.cloud.location import locations_pb2  # type: ignore
 from google.protobuf import json_format
 import grpc  # type: ignore
 from requests import __version__ as requests_version
@@ -290,6 +291,52 @@ class CloudSchedulerRestInterceptor:
         """
         return response
 
+    def pre_get_location(
+        self,
+        request: locations_pb2.GetLocationRequest,
+        metadata: Sequence[Tuple[str, str]],
+    ) -> Tuple[locations_pb2.GetLocationRequest, Sequence[Tuple[str, str]]]:
+        """Pre-rpc interceptor for get_location
+
+        Override in a subclass to manipulate the request or metadata
+        before they are sent to the CloudScheduler server.
+        """
+        return request, metadata
+
+    def post_get_location(
+        self, response: locations_pb2.Location
+    ) -> locations_pb2.Location:
+        """Post-rpc interceptor for get_location
+
+        Override in a subclass to manipulate the response
+        after it is returned by the CloudScheduler server but before
+        it is returned to user code.
+        """
+        return response
+
+    def pre_list_locations(
+        self,
+        request: locations_pb2.ListLocationsRequest,
+        metadata: Sequence[Tuple[str, str]],
+    ) -> Tuple[locations_pb2.ListLocationsRequest, Sequence[Tuple[str, str]]]:
+        """Pre-rpc interceptor for list_locations
+
+        Override in a subclass to manipulate the request or metadata
+        before they are sent to the CloudScheduler server.
+        """
+        return request, metadata
+
+    def post_list_locations(
+        self, response: locations_pb2.ListLocationsResponse
+    ) -> locations_pb2.ListLocationsResponse:
+        """Post-rpc interceptor for list_locations
+
+        Override in a subclass to manipulate the response
+        after it is returned by the CloudScheduler server but before
+        it is returned to user code.
+        """
+        return response
+
 
 @dataclasses.dataclass
 class CloudSchedulerRestStub:
@@ -416,7 +463,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.CreateJobRequest):
                     The request object. Request message for
                 [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -427,7 +473,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.gcs_job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -516,7 +562,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.DeleteJobRequest):
                     The request object. Request message for deleting a job using
                 [DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -592,7 +637,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.GetJobRequest):
                     The request object. Request message for
                 [GetJob][google.cloud.scheduler.v1.CloudScheduler.GetJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -603,7 +647,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -683,7 +727,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.ListJobsRequest):
                     The request object. Request message for listing jobs using
                 [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -773,7 +816,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.PauseJobRequest):
                     The request object. Request message for
                 [PauseJob][google.cloud.scheduler.v1.CloudScheduler.PauseJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -784,7 +826,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -873,7 +915,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.ResumeJobRequest):
                     The request object. Request message for
                 [ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -884,7 +925,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -973,7 +1014,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.RunJobRequest):
                     The request object. Request message for forcing a job to run now using
                 [RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -984,7 +1024,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -1049,9 +1089,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
         def __hash__(self):
             return hash("UpdateJob")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
-            "updateMask": {},
-        }
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1075,7 +1113,6 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 request (~.cloudscheduler.UpdateJobRequest):
                     The request object. Request message for
                 [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1086,7 +1123,7 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
                 ~.gcs_job.Job:
                     Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
             """
 
@@ -1199,6 +1236,140 @@ class CloudSchedulerRestTransport(CloudSchedulerTransport):
         # In C++ this would require a dynamic_cast
         return self._UpdateJob(self._session, self._host, self._interceptor)  # type: ignore
 
+    @property
+    def get_location(self):
+        return self._GetLocation(self._session, self._host, self._interceptor)  # type: ignore
+
+    class _GetLocation(CloudSchedulerRestStub):
+        def __call__(
+            self,
+            request: locations_pb2.GetLocationRequest,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: Optional[float] = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+        ) -> locations_pb2.Location:
+
+            r"""Call the get location method over HTTP.
+
+            Args:
+                request (locations_pb2.GetLocationRequest):
+                    The request object for GetLocation method.
+                retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                    should be retried.
+                timeout (float): The timeout for this request.
+                metadata (Sequence[Tuple[str, str]]): Strings which should be
+                    sent along with the request as metadata.
+
+            Returns:
+                locations_pb2.Location: Response from GetLocation method.
+            """
+
+            http_options: List[Dict[str, str]] = [
+                {
+                    "method": "get",
+                    "uri": "/v1/{name=projects/*/locations/*}",
+                },
+            ]
+
+            request, metadata = self._interceptor.pre_get_location(request, metadata)
+            request_kwargs = json_format.MessageToDict(request)
+            transcoded_request = path_template.transcode(http_options, **request_kwargs)
+
+            uri = transcoded_request["uri"]
+            method = transcoded_request["method"]
+
+            # Jsonify the query params
+            query_params = json.loads(json.dumps(transcoded_request["query_params"]))
+
+            # Send the request
+            headers = dict(metadata)
+            headers["Content-Type"] = "application/json"
+
+            response = getattr(self._session, method)(
+                "{host}{uri}".format(host=self._host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params),
+            )
+
+            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+            # subclass.
+            if response.status_code >= 400:
+                raise core_exceptions.from_http_response(response)
+
+            resp = locations_pb2.Location()
+            resp = json_format.Parse(response.content.decode("utf-8"), resp)
+            resp = self._interceptor.post_get_location(resp)
+            return resp
+
+    @property
+    def list_locations(self):
+        return self._ListLocations(self._session, self._host, self._interceptor)  # type: ignore
+
+    class _ListLocations(CloudSchedulerRestStub):
+        def __call__(
+            self,
+            request: locations_pb2.ListLocationsRequest,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: Optional[float] = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+        ) -> locations_pb2.ListLocationsResponse:
+
+            r"""Call the list locations method over HTTP.
+
+            Args:
+                request (locations_pb2.ListLocationsRequest):
+                    The request object for ListLocations method.
+                retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                    should be retried.
+                timeout (float): The timeout for this request.
+                metadata (Sequence[Tuple[str, str]]): Strings which should be
+                    sent along with the request as metadata.
+
+            Returns:
+                locations_pb2.ListLocationsResponse: Response from ListLocations method.
+            """
+
+            http_options: List[Dict[str, str]] = [
+                {
+                    "method": "get",
+                    "uri": "/v1/{name=projects/*}/locations",
+                },
+            ]
+
+            request, metadata = self._interceptor.pre_list_locations(request, metadata)
+            request_kwargs = json_format.MessageToDict(request)
+            transcoded_request = path_template.transcode(http_options, **request_kwargs)
+
+            uri = transcoded_request["uri"]
+            method = transcoded_request["method"]
+
+            # Jsonify the query params
+            query_params = json.loads(json.dumps(transcoded_request["query_params"]))
+
+            # Send the request
+            headers = dict(metadata)
+            headers["Content-Type"] = "application/json"
+
+            response = getattr(self._session, method)(
+                "{host}{uri}".format(host=self._host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params),
+            )
+
+            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+            # subclass.
+            if response.status_code >= 400:
+                raise core_exceptions.from_http_response(response)
+
+            resp = locations_pb2.ListLocationsResponse()
+            resp = json_format.Parse(response.content.decode("utf-8"), resp)
+            resp = self._interceptor.post_list_locations(resp)
+            return resp
+
     @property
     def kind(self) -> str:
         return "rest"
