@@ -35,7 +35,7 @@ __protobuf__ = proto.module(
 
 class Job(proto.Message):
     r"""Configuration for a job.
-    The maximum allowed size for a job is 100KB.
+    The maximum allowed size for a job is 1MB.
 
     This message has `oneof`_ fields (mutually exclusive fields).
     For each oneof, at most one member field can be set at the same time.
@@ -94,7 +94,7 @@ class Job(proto.Message):
 
             The schedule can be either of the following types:
 
-            -  `Crontab <http://en.wikipedia.org/wiki/Cron#Overview>`__
+            -  `Crontab <https://en.wikipedia.org/wiki/Cron#Overview>`__
             -  English-like
                `schedule <https://cloud.google.com/scheduler/docs/configuring/cron-job-schedules>`__
 
@@ -151,14 +151,27 @@ class Job(proto.Message):
             Cloud Scheduler will retry the job according to the
             [RetryConfig][google.cloud.scheduler.v1.RetryConfig].
 
-            The allowed duration for this deadline is:
+            The default and the allowed values depend on the type of
+            target:
 
             -  For [HTTP
-               targets][google.cloud.scheduler.v1.Job.http_target],
-               between 15 seconds and 30 minutes.
+               targets][google.cloud.scheduler.v1.Job.http_target], the
+               default is 3 minutes. The deadline must be in the
+               interval [15 seconds, 30 minutes].
+
             -  For [App Engine HTTP
                targets][google.cloud.scheduler.v1.Job.app_engine_http_target],
-               between 15 seconds and 24 hours.
+               0 indicates that the request has the default deadline.
+               The default deadline depends on the scaling type of the
+               service: 10 minutes for standard apps with automatic
+               scaling, 24 hours for standard apps with manual and basic
+               scaling, and 60 minutes for flex apps. If the request
+               deadline is set, it must be in the interval [15 seconds,
+               24 hours 15 seconds].
+
+            -  For [Pub/Sub
+               targets][google.cloud.scheduler.v1.Job.pubsub_target],
+               this field is ignored.
     """
 
     class State(proto.Enum):
@@ -312,7 +325,7 @@ class RetryConfig(proto.Message):
             A job's retry interval starts at
             [min_backoff_duration][google.cloud.scheduler.v1.RetryConfig.min_backoff_duration],
             then doubles ``max_doublings`` times, then increases
-            linearly, and finally retries retries at intervals of
+            linearly, and finally retries at intervals of
             [max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration]
             up to
             [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count]
