@@ -267,8 +267,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1beta1.types.ListJobsRequest, dict]]):
-                The request object. Request message for listing jobs
-                using
+                The request object. Request message for listing jobs using
                 [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
             parent (:class:`str`):
                 Required. The location name. For example:
@@ -750,8 +749,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1beta1.types.DeleteJobRequest, dict]]):
-                The request object. Request message for deleting a job
-                using
+                The request object. Request message for deleting a job using
                 [DeleteJob][google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob].
             name (:class:`str`):
                 Required. The job name. For example:
@@ -1103,8 +1101,7 @@ class CloudSchedulerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.scheduler_v1beta1.types.RunJobRequest, dict]]):
-                The request object. Request message for forcing a job to
-                run now using
+                The request object. Request message for forcing a job to run now using
                 [RunJob][google.cloud.scheduler.v1beta1.CloudScheduler.RunJob].
             name (:class:`str`):
                 Required. The job name. For example:
